==> uimaj-3.2.0-source-release.zip: uimaj-3.2.0/uimaj-ep-configurator/src/main/java/org/apache/uima/taeconfigurator/StandardStrings.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.uima.taeconfigurator;


/**
 * The Interface StandardStrings.
 */
public interface StandardStrings {
  
  /** The Constant S_ADD. */
  public static final String S_ADD = "Add...";

  /** The Constant S_EDIT. */
  public static final String S_EDIT = "Edit...";

  /** The Constant S_EDIT_TIP. */
  public static final String S_EDIT_TIP = "Click here to edit the selected item. You can also double-click the item to edit it.";

  /** The Constant S_REMOVE. */
  public static final String S_REMOVE = "Remove";

  /** The Constant S_REMOVE_TIP. */
  public static final String S_REMOVE_TIP = "Click here to remove the selected item.  You can also use the delete key.";

  /** The Constant S_UP. */
  public static final String S_UP = "Up";

  /** The Constant S_UP_TIP. */
  public static final String S_UP_TIP = "Click here to move the selected item up by one.";

  /** The Constant S_DOWN. */
  public static final String S_DOWN = "Down";

  /** The Constant S_DOWN_TIP. */
  public static final String S_DOWN_TIP = "Click here to move the selected item down by one.";

  /** The Constant S_DESCRIPTION. */
  public static final String S_DESCRIPTION = "Description:";

  /** The Constant S_. */
  public static final String S_ = "";

  /** The Constant S_EXPORT. */
  public static final String S_EXPORT = "Export...";

  /** The Constant S_EXPORT_TIP. */
  public static final String S_EXPORT_TIP = "Export to an importable part, and substitute an Import for that part here";
}

==> uimaj-3.3.0-source-release.zip: uimaj-3.3.0/uimaj-ep-configurator/src/main/java/org/apache/uima/taeconfigurator/StandardStrings.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.uima.taeconfigurator;

/**
 * The Interface StandardStrings.
 */
public interface StandardStrings {

  /** The Constant S_ADD. */
  String S_ADD = "Add...";

  /** The Constant S_EDIT. */
  String S_EDIT = "Edit...";

  /** The Constant S_EDIT_TIP. */
  String S_EDIT_TIP = "Click here to edit the selected item. You can also double-click the item to edit it.";

  /** The Constant S_REMOVE. */
  String S_REMOVE = "Remove";

  /** The Constant S_REMOVE_TIP. */
  String S_REMOVE_TIP = "Click here to remove the selected item.  You can also use the delete key.";

  /** The Constant S_UP. */
  String S_UP = "Up";

  /** The Constant S_UP_TIP. */
  String S_UP_TIP = "Click here to move the selected item up by one.";

  /** The Constant S_DOWN. */
  String S_DOWN = "Down";

  /** The Constant S_DOWN_TIP. */
  String S_DOWN_TIP = "Click here to move the selected item down by one.";

  /** The Constant S_DESCRIPTION. */
  String S_DESCRIPTION = "Description:";

  /** The Constant S_. */
  String S_ = "";

  /** The Constant S_EXPORT. */
  String S_EXPORT = "Export...";

  /** The Constant S_EXPORT_TIP. */
  String S_EXPORT_TIP = "Export to an importable part, and substitute an Import for that part here";
}
